@@ -6,13 +6,20 @@ from functools import wraps
 from flask import request, current_app
 from werkzeug.routing import BaseConverter
 
-from trytond.config import CONFIG
+from trytond.version import VERSION as trytond_version
+trytond_version = tuple(map(int, trytond_version.split('.')))
+try:
+    from trytond.config import config
+except ImportError:
+    from trytond.config import CONFIG as config
+
 from trytond.pool import Pool
 from trytond.transaction import Transaction
 from trytond.cache import Cache
 from trytond import backend
 
-__version__ = '0.2'
+__version__ = '0.3'
+__all__ = ['Tryton', 'tryton_transaction']
 
 
 class Tryton(object):
@@ -28,11 +35,11 @@ class Tryton(object):
         user = app.config.setdefault('TRYTON_USER', 0)
         configfile = app.config.setdefault('TRYTON_CONFIG', None)
 
-        CONFIG.update_etc(configfile)
+        config.update_etc(configfile)
 
         # 3.0 compatibility
-        if hasattr(CONFIG, 'set_timezone'):
-            CONFIG.set_timezone()
+        if hasattr(config, 'set_timezone'):
+            config.set_timezone()
 
         self.pool = Pool(database)
         with Transaction().start(database, user, readonly=True):
@@ -81,7 +88,11 @@ class Tryton(object):
             def wrapper(*args, **kwargs):
                 tryton = current_app.extensions['Tryton']
                 database = current_app.config['TRYTON_DATABASE']
-                Cache.clean(database)
+                if trytond_version >= (3, 3):
+                    with Transaction().start(database, 0):
+                        Cache.clean(database)
+                else:
+                    Cache.clean(database)
 
                 if user is None:
                     transaction_user = get_value(
@@ -101,8 +112,12 @@ class Tryton(object):
                         if tryton.context_callback:
                             transaction_context = tryton.context_callback()
                         transaction_context.update(get_value(context) or {})
+                if trytond_version >= (3, 3):
+                    retry = config.getint('database', 'retry')
+                else:
+                    retry = int(config['retry'])
 
-                for count in range(int(CONFIG['retry']), -1, -1):
+                for count in range(retry, -1, -1):
                     with Transaction().start(database, transaction_user,
                             readonly=is_readonly,
                             context=transaction_context) as transaction:
@@ -121,7 +136,10 @@ class Tryton(object):
                         except Exception:
                             cursor.rollback()
                             raise
-                    Cache.resets(database)
+                        if trytond_version >= (3, 3):
+                            Cache.resets(database)
+                    if trytond_version < (3, 3):
+                        Cache.resets(database)
                     return result
             return wrapper
         return decorator
